# coding: utf-8

"""
    Generated by: https://github.com/openapi-json-schema-tools/openapi-json-schema-generator
"""

from nethsm.client.paths.keys_key_id_csr_pem.post.operation import ApiForPost


class KeysKeyIDCsrPem(
    ApiForPost,
):
    pass
