# coding: utf-8

"""
    Generated by: https://github.com/openapi-json-schema-tools/openapi-json-schema-generator
"""

from nethsm.client.paths.keys.get.operation import ApiForGet
from nethsm.client.paths.keys.post.operation import ApiForPost


class Keys(
    ApiForGet,
    ApiForPost,
):
    pass
